@@ -60,33 +60,40 @@ pub fn fraction(value: Float, options: Options, colors: &Colors, n: usize) -> St
                             mul = n.to_string()
                         }
                     }
-                    format!(
-                        "{}{}{}{}{}{}",
-                        sign,
-                        mul,
-                        if i == 1 { "sqrt" } else { "cbrt" },
-                        if options.color == crate::Auto::True
-                        {
-                            colors.brackets[n % colors.brackets.len()].to_owned()
-                                + "("
-                                + &colors.text
-                        }
-                        else
-                        {
-                            "(".to_string()
-                        },
-                        num,
-                        if options.color == crate::Auto::True
-                        {
-                            colors.brackets[n % colors.brackets.len()].to_owned()
-                                + ")"
-                                + &colors.text
-                        }
-                        else
-                        {
-                            ")".to_string()
-                        }
-                    )
+                    if num != 1
+                    {
+                        format!(
+                            "{}{}{}{}{}{}",
+                            sign,
+                            mul,
+                            if i == 1 { "sqrt" } else { "cbrt" },
+                            if options.color == crate::Auto::True
+                            {
+                                colors.brackets[n % colors.brackets.len()].to_owned()
+                                    + "("
+                                    + &colors.text
+                            }
+                            else
+                            {
+                                "(".to_string()
+                            },
+                            num,
+                            if options.color == crate::Auto::True
+                            {
+                                colors.brackets[n % colors.brackets.len()].to_owned()
+                                    + ")"
+                                    + &colors.text
+                            }
+                            else
+                            {
+                                ")".to_string()
+                            }
+                        )
+                    }
+                    else
+                    {
+                        String::new()
+                    }
                 }
             }
             else
@@ -262,7 +269,7 @@ pub fn fraction(value: Float, options: Options, colors: &Colors, n: usize) -> St
                             }
                             (true, false) =>
                             {
-                                div *= recip.clone().pow(if i == 1 { 2 } else { 3 });
+                                div *= recip.clone();
                                 format!(
                                     "{sign}{}/{}{}{}{}",
                                     if mul.is_empty() { "1" } else { &mul },
@@ -387,7 +394,10 @@ pub fn c_to_rational(value: Complex, options: Options) -> Vec<Number>
     let mut vec = Vec::new();
     if let Some(n) = re
     {
-        vec.push(Number::from(Complex::with_val(options.prec, if sign_re{n.0}else{-n.0}), None));
+        vec.push(Number::from(
+            Complex::with_val(options.prec, if sign_re { n.0 } else { -n.0 }),
+            None,
+        ));
         vec.push(Number::from(Complex::with_val(options.prec, n.1), None));
     }
     else
@@ -397,7 +407,10 @@ pub fn c_to_rational(value: Complex, options: Options) -> Vec<Number>
     }
     if let Some(n) = im
     {
-        vec.push(Number::from(Complex::with_val(options.prec, if sign_im{n.0}else{-n.0}), None));
+        vec.push(Number::from(
+            Complex::with_val(options.prec, if sign_im { n.0 } else { -n.0 }),
+            None,
+        ));
         vec.push(Number::from(Complex::with_val(options.prec, n.1), None));
     }
     vec
