@@ -130,6 +130,11 @@ pub fn functions() -> HashSet<&'static str>
         "any",
         "eigenvalues",
         "eigenvectors",
+        "rref",
+        "ker",
+        "ran",
+        "rank",
+        "null",
         "mat",
         "prime",
         "reverse",
@@ -360,9 +365,9 @@ pub fn functions_with_args() -> HashSet<&'static str>
         "acoth(x)",
         "cis(x)",
         "ln(x)",
-        "ceil(x)",
-        "floor(x)",
-        "round(x)",
+        "ceil(x(,d))",
+        "floor(x(,d))",
+        "round(x(,d))",
         "recip(x)",
         "exp(x(,y))",
         "log((b,)p)",
@@ -377,9 +382,9 @@ pub fn functions_with_args() -> HashSet<&'static str>
         "sgn(x)",
         "arg(x)",
         "cbrt(x)",
-        "fract(x)",
-        "int(x)",
-        "trunc(x)",
+        "fract(x(,d))",
+        "int(x(,d))",
+        "trunc(x(,d))",
         "fact(x)",
         "subfact(x)",
         "sinc(x)",
@@ -398,6 +403,11 @@ pub fn functions_with_args() -> HashSet<&'static str>
         "any(vec)",
         "eigenvalues(mat)",
         "eigenvectors(mat)",
+        "rref(mat)",
+        "ker(mat)",
+        "ran(mat)",
+        "rank(mat)",
+        "null(mat)",
         "mat(a,f(a),start,end)",
         "reverse(vec)",
         "flatten(mat)",
