@@ -4,7 +4,7 @@ use crate::misc::get_terminal_dimensions;
 use crate::misc::get_terminal_dimensions_pixel;
 use crate::{
     complex::{
-        NumStr,
+        set_prec, NumStr,
         NumStr::{Func, Matrix, Num, Vector},
     },
     load_vars::set_commands_or_vars,
@@ -38,6 +38,13 @@ pub fn graph(
 {
     thread::spawn(move || {
         let mut func = Vec::new();
+        let mut last_prec = options.graph_prec;
+        if options.prec != options.graph_prec
+        {
+            options.prec = options.graph_prec;
+            vars.iter_mut()
+                .for_each(|v| set_prec(&mut v.parsed, &mut v.funcvars, options.prec));
+        }
         for (i, s) in input.clone().iter().enumerate()
         {
             if s.is_empty()
@@ -45,12 +52,11 @@ pub fn graph(
                 continue;
             }
             {
-                options.prec = options.graph_prec;
                 let split = s.split(';');
                 let count = split.clone().count();
                 if count != 1
                 {
-                    input[i] = split.clone().last().unwrap().to_string();
+                    input[i] = split.clone().next_back().unwrap().to_string();
                     for (i, s) in split.enumerate()
                     {
                         if i == count - 1
@@ -87,7 +93,13 @@ pub fn graph(
             {
                 return;
             }
-            options.prec = options.graph_prec;
+            if last_prec != options.graph_prec
+            {
+                options.prec = options.graph_prec;
+                last_prec = options.graph_prec;
+                vars.iter_mut()
+                    .for_each(|v| set_prec(&mut v.parsed, &mut v.funcvars, options.prec));
+            }
             func.push(
                 match input_var(
                     &input[i],
@@ -167,6 +179,8 @@ pub fn graph(
             (dimen, re_or_im, line, failed, rec_re, rec_im) = handle.join().unwrap();
             if failed
             {
+                writeln!(stdin, "exit").unwrap();
+                gnuplot.wait().unwrap();
                 return;
             }
             lines.push(
@@ -213,6 +227,8 @@ pub fn graph(
                 prompt(options, &colors)
             );
             stdout().flush().unwrap();
+            writeln!(stdin, "exit").unwrap();
+            gnuplot.wait().unwrap();
             return;
         }
         {
@@ -443,12 +459,14 @@ pub fn graph(
                 .map(|p| p.unwrap().path().display().to_string())
                 .collect();
             paths.sort_by_key(|dir| {
-                let st = dir.split('/').last().unwrap();
+                let st = dir.split('/').next_back().unwrap();
                 st[2..].to_string()
             });
             if paths.is_empty()
             {
                 println!("\x1b[G\x1b[Knothing to graph for {}\x1b[G", input.join("#"));
+                writeln!(stdin, "exit").unwrap();
+                gnuplot.wait().unwrap();
                 return;
             }
             writeln!(
