@@ -14,6 +14,8 @@ mod tests;
 mod units;
 //make dependencys optional via features
 //add symbolica as an optional feature
+//rayon-ize graphs, and maybe area
+//fix ||x|-1|
 //lib, gui
 use crate::{
     complex::NumStr,
@@ -606,7 +608,7 @@ fn main()
                     let count = split.clone().count();
                     if count != 1
                     {
-                        unparsed = split.clone().last().unwrap().to_vec();
+                        unparsed = split.clone().next_back().unwrap().to_vec();
                         for (i, s) in split.enumerate()
                         {
                             if i == count - 1
@@ -1378,7 +1380,8 @@ fn main()
                         }
                         else
                         {
-                            if slow {
+                            if slow
+                            {
                                 input.pop();
                             }
                             placement = input.len();
@@ -1461,7 +1464,8 @@ fn main()
                         }
                         else
                         {
-                            if slow {
+                            if slow
+                            {
                                 input.pop();
                             }
                             placement = input.len();
